@@ -4,7 +4,7 @@ use crate::types::{MainConfig, ChainConfig};
 use clarity_repl::{repl, Terminal};
 
 
-pub fn load_session(start_repl: bool) -> Result<(), String> {
+pub fn load_session(start_repl: bool, env: String) -> Result<repl::SessionSettings, String> {
     let mut settings = repl::SessionSettings::default();
 
     let root_path = env::current_dir().unwrap();
@@ -13,7 +13,14 @@ pub fn load_session(start_repl: bool) -> Result<(), String> {
 
     let mut chain_config_path = root_path.clone();
     chain_config_path.push("settings");
-    chain_config_path.push("Development.toml");
+
+    chain_config_path.push(if env == "mocknet" {
+        "Mocknet.toml"
+    } else if env == "testnet" {
+        "Testnet.toml"
+    } else {
+        "Development.toml"
+    });
 
     let mut project_config = MainConfig::from_path(&project_config_path);
     let chain_config = ChainConfig::from_path(&chain_config_path);
@@ -77,11 +84,11 @@ pub fn load_session(start_repl: bool) -> Result<(), String> {
     settings.initial_deployer = initial_deployer;
 
     if start_repl {
-        let mut terminal = Terminal::new(settings);
+        let mut terminal = Terminal::new(settings.clone());
         terminal.start();
     } else {
-        let mut session = repl::Session::new(settings);
+        let mut session = repl::Session::new(settings.clone());
         session.check()?;
     }
-    Ok(())
+    Ok(settings)
 }
