@@ -56,7 +56,13 @@ pub struct AccountConfig {
 
 impl ChainConfig {
     pub fn from_path(path: &PathBuf) -> ChainConfig {
-        let path = File::open(path).unwrap();
+        let path = match File::open(path) {
+            Ok(path) => path,
+            Err(_) => {
+                let error = format!("Unable to open file {:?}", path.to_str());
+                panic!(error)
+            }
+        };
         let mut config_file_reader = BufReader::new(path);
         let mut config_file_buffer = vec![];
         config_file_reader
