@@ -1,5 +1,5 @@
 mod project_config;
 mod chain_config;
 
-pub use project_config::{MainConfig, MainConfigFile, ContractConfig};
+pub use project_config::{MainConfig, MainConfigFile, ContractConfig, LinkConfig};
 pub use chain_config::{ChainConfig, ChainConfigFile};
